<template>
  <div class="row" style="position: absolute; top: 5px; width: 100%">
    <div
      :class="
        !hasReportDropDown
          ? !hasExport
            ? !addNew
              ? 'col-6'
              : 'col-8'
            : !addNew
            ? 'col-6'
            : 'col-4 col-sm-1'
          : 'col-6'
      "
    ></div>

    <div class="col-2">
      <div v-if="hasReportDropDown">
        <el-select
          v-model="currentReportTypeTrans"
          class="form-select-solid"
          :placeholder="$t('nav.reports')"
        >
          <el-option
            v-for="(type, idx) in reportTypes"
            :key="idx"
            :label="$t('nav.' + type)"
            :value="$t('nav.' + type)"
          >
            <router-link
              class="dropdown-item"
              :to="{ name: 'show-reports', params: { type: type } }"
            >
              {{ $t("nav." + type) }}
            </router-link>
          </el-option>
        </el-select>
      </div>
    </div>
    <div class="col-2">
      <div v-if="hasExport">
        <el-select
          v-model="export_value"
          class="form-select-solid"
          :placeholder="$t('app.export')"
        >
          <el-option
            :class="$i18n.locale == 'ar' ? 'hacen_algeria' : ''"
            value=""
            selected
            >{{ $t("app.export") }}</el-option
          >
          <el-option
            :class="$i18n.locale == 'ar' ? 'hacen_algeria' : ''"
            :label="$t('app.excel')"
            :value="$t('app.excel')"
          >
            <download-excel
              :style="$i18n.locale == 'ar' ? '' : 'text-align: left'"
              :fetch="fetchExport"
              :fields="json.json_fields"
              :before-generate="startDownload"
              :before-finish="finishDownload"
              :worksheet="refs"
              :name="refs + '.xls'"
              >{{ $t("app.excel") }}
            </download-excel>
          </el-option>
          <el-option
            :class="$i18n.locale == 'ar' ? 'hacen_algeria' : ''"
            :label="$t('app.csv')"
            :value="$t('app.csv')"
          >
            <download-excel
              :style="$i18n.locale == 'ar' ? '' : 'text-align: left'"
              :fetch="fetchExport"
              :fields="json.json_fields"
              :before-generate="startDownload"
              :before-finish="finishDownload"
              type="csv"
              :worksheet="refs"
              :name="refs + '.csv'"
              >{{ $t("app.csv") }}
            </download-excel>
          </el-option>
          <el-option
            :class="$i18n.locale == 'ar' ? 'hacen_algeria' : ''"
            :label="$t('app.print')"
            :value="$t('app.print')"
          >
            <a v-print="'#printMe'">{{ $t("app.print") }} </a>
          </el-option>
        </el-select>
      </div>
    </div>
    <div class="col-2">
      <ShowEntries :perPage="this.perPage" v-on:showChange="handelShowChange">
      </ShowEntries>
    </div>

    <div class="col-2 col-sm-5">
      <h4
        class="mb-0"
        :class="$i18n.locale == 'ar' ? 'font-size-24' : 'font-size-16'"
      >
        <router-link
          v-if="addNew"
          :to="'/' + refs + '/create'"
          class="btn btn-sm btn-light-primary w-100"
          :class="[$i18n.locale == 'ar' ? 'hacen_algeria' : '']"
        >
          <i class="mdi mdi-plus-circle"></i>
          {{ $t("app.send") }}
        </router-link>
        <a v-else class="btn btn-primary mb-2 opacity-0">hidden</a>
      </h4>
    </div>
  </div>
</template>

<script lang="ts">
import iziToast from "izitoast";
import { defineComponent } from "vue";
import ShowEntries from "@/components/ShowEntries.vue";
import ApiService from "@/core/services/ApiService";

export default defineComponent({
  name: "BulkAction",
  components: { ShowEntries },
  props: [
    "bulkLoading",
    "hasReportDropDown",
    "hasMultiSelect",
    "hasExport",
    "exportLoading",
    "selected",
    "fields",
    "search",
    "category_id",
    "time",
    "date",
    "target",
    "status",
    "refs",
    "addNew",
    "bus",
  ],
  data() {
    return {
      apiDomainName: (window as any).apiDomainName,
      perPage: 10,
      currentReportType: "invoices",
      currentReportTypeTrans: this.$t("nav.invoices"),
      reportTypes: ["invoices"],
      export_value: "",
      json: {
        json_fields: this.$props.fields,
        json_data: [],
        json_meta: [
          [
            {
              key: "charset",
              value: "utf-8",
            },
          ],
        ],
      },
      expLoading: this.$props.exportLoading,
      ids: this.$props.selected,

      importFile: "",
      company_id: "",
      row: {
        slug: "",
        parent_id: "",
      },
    };
  },
  created() {
    this.bus.on("companyChanged", (event) => {
      this.company_id = event.company_id;
    });
  },
  watch: {
    selected: function (new_value) {
      this.ids = new_value;
    },
    exportLoading: function (new_value) {
      this.expLoading = new_value;
    },
  },
  methods: {
    async fetchExport() {
      const res = await this.axios.post(
        this.refs +
          "/export?locale=" +
          this.$i18n.locale +
          "&search=" +
          this.$props.search +
          "&category_id=" +
          this.$props.category_id +
          "&time=" +
          this.$props.time +
          "&date=" +
          this.$props.date +
          "&target=" +
          this.$props.target +
          "&status=" +
          this.$props.status +
          "&paginate=" +
          this.perPage
      );
      return res.data.rows;
    },
    startDownload() {
      this.expLoading = true;
    },

    finishDownload() {
      this.expLoading = false;
      iziToast.success({
        icon: "bx bx-wink-smile",
        title: "",
        message: "تم استخراج الملف بنجاح",
      });
    },
    toCompanyInvoices() {
      const company_id = this.company_id
        ? this.company_id
        : ApiService.getUser().company.encrypt_id;
      window.open(
        this.apiDomainName +
          "/invoices/company/" +
          company_id +
          "/pdf?locale=" +
          this.$i18n.locale,
        "_blank"
      );
    },
    handelShowChange(event) {
      this.perPage = event;
      this.$emit("fetchDate");
    },
  },
});
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style scoped>
.width-100px {
  width: 100px;
}

.width-110px {
  width: 110px;
}
</style>
